%
% Simple matlab script to generate slice plots of the NSCAT1 dual-polarization
% polarization model function for various azimuth and incidence angles,
% wind speeds and directions, and antenna azimuth angles.  Uses the
% NSCAT1.m script
%
% Written by D.G. Long at BYU Jan 2012
%

clear
figure(1);clf
t=['-',':','.','*','s','t'];

% first generate sigma^0 versus wind speed at several incidence angles
subplot(2,1,1)
spds=2:2:20;   % wind speed in m/s
incs=20:10:60; % incidence angle in deg 
% note: NSCAT1 is not defined for theta less than 15 deg
z=zeros(size(spds));  % zero-filled array (same as 0*spds)

for i=1:length(incs)
  sig=NSCAT1([spds' z' z' incs(i)+z' 1+z']);
  semilogx(spds,10*log10(sig),['b' t(i)]);
  hold on;
end
for i=1:length(incs)
  sig=NSCAT1([spds' z' z' incs(i)+z' 2+z']);
  semilogx(spds,10*log10(sig),['r' t(i)]);  
end
hold off;
title('Ku-band NSCAT1');
xlabel('Wind speed U (m/s)');
ylabel('Backscattering (dB)');
legend('20 deg','30 deg','40 deg','50 deg','60 deg')

% generate sigma^0 versus wind direction at several speeds
subplot(2,1,2)
az=0:10:360;   % antenna azimuth angle (deg)
spds=[5,10,15,20,30]; % wind speeds in m/s

for i=1:length(spds)
  sig=NSCAT1([spds(i)+0*az' az' 0*az' 45+0*az', 1+0*az']);
  plot(az,10*log10(sig),['b',t(i)]);
  hold on;
end
for i=1:length(spds)
  sig=NSCAT1([spds(i)+0*az' az' 0*az' 45+0*az', 2+0*az']);
  plot(az,10*log10(sig),['r',t(i)]);
end
hold off;
title('Ku-band NSCAT1 (blue=v-pol, red=h-pol)');
xlabel('Relative wind direction (deg)');
ylabel('Backscattering (dB)');
legend('5 m/s','20 m/s','15 m/s','20 m/s','30 m/s')

% save graphics as a figure
save -dpng NSCAT1.png